@@ -287,7 +287,7 @@ impl Query {
                                 subqueries.push(Box::new(data::value.eq_any(values?)))
                             }
                             QueryComponent::Contains(q_value) => subqueries
-                                .push(Box::new(data::value.like(format!("%{}%", q_value)))),
+                                .push(Box::new(data::value.like(format!("J%{}%", q_value)))),
                             QueryComponent::Any => {}
                         };
 
