@@ -9,15 +9,16 @@ use std::{
     sync::{Arc, Mutex},
 };
 
+use self::image::ImagePath;
 use self::text::TextPath;
 use self::video::VideoPath;
 
-
+pub mod image;
 pub mod text;
 pub mod video;
 
 pub trait Previewable {
-    fn get_thumbnail(&self) -> Result<Vec<u8>>;
+    fn get_thumbnail(&self) -> Result<Option<Vec<u8>>>;
 }
 pub struct PreviewStore {
     path: PathBuf,
@@ -48,28 +49,35 @@ impl PreviewStore {
         }
     }
 
-    pub fn get(&self, hash: Hash) -> Result<PathBuf> {
+    pub fn get(&self, hash: Hash) -> Result<Option<PathBuf>> {
         let path_mutex = self.get_path(&hash);
         let thumbpath = path_mutex.lock().unwrap();
         if thumbpath.exists() {
-            Ok(thumbpath.clone())
+            Ok(Some(thumbpath.clone()))
         } else {
             let connection = self.db.connection()?;
             let files = connection.retrieve_file(hash)?;
             if let Some(file) = files.get(0) {
-
-                let data = match tree_magic_mini::from_filepath(&file.path) {
+                let preview = match tree_magic_mini::from_filepath(&file.path) {
                     Some(tm) if tm.starts_with("text") => Ok(TextPath(&file.path).get_thumbnail()?),
-                    Some(tm) if tm.starts_with("video") => Ok(VideoPath(&file.path).get_thumbnail()?),
+                    Some(tm) if tm.starts_with("video") => {
+                        Ok(VideoPath(&file.path).get_thumbnail()?)
+                    }
+                    Some(tm) if tm.starts_with("image") => {
+                        Ok(ImagePath(&file.path).get_thumbnail()?)
+                    }
                     Some(unknown) => Err(anyhow!("No capability for {:?} thumbnails.", unknown)),
-                    _ => Err(anyhow!("Unknown file type, or file doesn't exist."))
+                    _ => Err(anyhow!("Unknown file type, or file doesn't exist.")),
                 }?;
 
-                std::fs::create_dir_all(&self.path)?;
-                let mut file = File::create(&*thumbpath)?;
-                file.write_all(&data)?;
-
-                Ok(thumbpath.clone())
+                if let Some(data) = preview {
+                    std::fs::create_dir_all(&self.path)?;
+                    let mut file = File::create(&*thumbpath)?;
+                    file.write_all(&data)?;
+                    Ok(Some(thumbpath.clone()))
+                } else {
+                    Ok(None)
+                }
             } else {
                 Err(anyhow!("Object not found, or is not a file."))
             }
