@@ -413,24 +413,32 @@ pub async fn get_info(state: web::Data<State>) -> Result<HttpResponse, Error> {
 pub async fn get_thumbnail(
     state: web::Data<State>,
     hash: web::Path<String>,
-) -> Result<NamedFile, Error> {
+) -> Result<Either<NamedFile, HttpResponse>, Error> {
     #[cfg(feature = "previews")]
     if let Some(preview_store) = &state.preview_store {
-        let address =
-            Address::decode(&decode(hash.into_inner()).map_err(ErrorInternalServerError)?)
-                .map_err(ErrorInternalServerError)?;
-        if let Address::Hash(hash) = address {
-            let preview_path = preview_store
-                .get(hash)
+        let hash = hash.into_inner();
+        let address = Address::decode(&decode(&hash).map_err(ErrorInternalServerError)?)
+            .map_err(ErrorInternalServerError)?;
+        if let Address::Hash(address_hash) = address {
+            let preview_result = preview_store
+                .get(address_hash)
                 .map_err(error::ErrorInternalServerError)?;
 
-            let mut file = NamedFile::open(&preview_path)?.disable_content_disposition();
-            if let Some(mime_type) = tree_magic_mini::from_filepath(&preview_path) {
-                if let Ok(mime) = mime_type.parse() {
-                    file = file.set_content_type(mime);
+            if let Some(preview_path) = preview_result {
+                let mut file = NamedFile::open(&preview_path)?.disable_content_disposition();
+                if let Some(mime_type) = tree_magic_mini::from_filepath(&preview_path) {
+                    if let Ok(mime) = mime_type.parse() {
+                        file = file.set_content_type(mime);
+                    }
                 }
+                return Ok(Either::A(file));
+            } else {
+                return Ok(Either::B(
+                    HttpResponse::SeeOther()
+                        .header(http::header::LOCATION, format!("/api/raw/{hash}"))
+                        .finish(),
+                ));
             }
-            return Ok(file);
         } else {
             return Err(ErrorBadRequest(
                 "Address does not refer to a previewable object.",
